.. _channelize:

********************************************
Channelization (`baseband_tasks.channelize`)
********************************************

`~baseband_tasks.channelize` contains tasks for basic channelization.

.. _channelize_api:

Reference/API
=============

.. automodapi:: baseband_tasks.channelize
   :no-inherited-members: